@@ -9,28 +9,28 @@
 # lost the next time ruby is built.
 
 module RbConfig
-  RUBY_VERSION.start_with?("3.3.") or
-    raise "ruby lib version (3.3.8) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION.start_with?("3.4.") or
+    raise "ruby lib version (3.4.2) doesn't match executable version (#{RUBY_VERSION})"
 
   # Ruby installed directory.
-  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/3.3.0/powerpc-netbsd")
+  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/3.4.0/powerpc-netbsd")
   # DESTDIR on make install.
   DESTDIR = '' unless defined? DESTDIR
   # The hash configurations stored.
   CONFIG = {}
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "3"
-  CONFIG["MINOR"] = "3"
-  CONFIG["TEENY"] = "8"
-  CONFIG["PATCHLEVEL"] = "144"
+  CONFIG["MINOR"] = "4"
+  CONFIG["TEENY"] = "2"
+  CONFIG["PATCHLEVEL"] = "28"
   CONFIG["INSTALL"] = '/usr/bin/install -c'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/pkg")
-  CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)33"
-  CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)33"
-  CONFIG["RUBY_SO_NAME"] = "ruby33"
+  CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)34"
+  CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)34"
+  CONFIG["RUBY_SO_NAME"] = "ruby34"
   CONFIG["exec"] = "exec"
-  CONFIG["ruby_pc"] = "ruby-3.3.8.pc"
+  CONFIG["ruby_pc"] = "ruby-3.4.2.pc"
   CONFIG["CC_WRAPPER"] = ""
   CONFIG["PACKAGE"] = "ruby"
   CONFIG["BUILTIN_TRANSSRCS"] = " enc/trans/newline.c"
@@ -45,7 +45,7 @@ module RbConfig
   CONFIG["RUBY_SEARCH_PATH"] = ""
   CONFIG["UNIVERSAL_INTS"] = ""
   CONFIG["UNIVERSAL_ARCHNAMES"] = ""
-  CONFIG["configure_args"] = " '--enable-shared' '--enable-install-static-library' '--without-git' '--program-suffix=33' '--with-soname=ruby33' '--with-ruby-version=3.3.0' '--with-ruby-pc=ruby-3.3.8.pc' '--enable-pthread' '--prefix=/usr/pkg' '--build=powerpc--netbsd' '--host=powerpc--netbsd' '--mandir=/usr/pkg/man' 'build_alias=powerpc--netbsd' 'host_alias=powerpc--netbsd' 'CC=gcc' 'CXX=c++' 'CFLAGS=-O2 -pthread -I/usr/include -I/usr/pkg/include' 'LDFLAGS=-Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -pthread' 'LIBS=' 'CPPFLAGS=-I/usr/include -I/usr/pkg/include' 'CXXFLAGS=-O2 -pthread -I/usr/include -I/usr/pkg/include'"
+  CONFIG["configure_args"] = " '--enable-shared' '--enable-install-static-library' '--without-git' '--program-suffix=34' '--with-soname=ruby34' '--with-ruby-version=3.4.0' '--with-ruby-pc=ruby-3.4.2.pc' '--enable-pthread' '--prefix=/usr/pkg' '--build=powerpc--netbsd' '--host=powerpc--netbsd' '--mandir=/usr/pkg/man' 'build_alias=powerpc--netbsd' 'host_alias=powerpc--netbsd' 'CC=gcc' 'CXX=c++' 'CFLAGS=-O2 -pthread -I/usr/include -I/usr/pkg/include' 'LDFLAGS=-Wl,-zrelro -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -pthread' 'LIBS=' 'CPPFLAGS=-I/usr/include -I/usr/pkg/include' 'CXXFLAGS=-O2 -pthread -I/usr/include -I/usr/pkg/include'"
   CONFIG["CONFIGURE"] = "configure"
   CONFIG["vendorarchdir"] = "$(vendorlibdir)/$(sitearch)"
   CONFIG["vendorlibdir"] = "$(vendordir)/$(ruby_version)"
@@ -55,7 +55,7 @@ module RbConfig
   CONFIG["sitedir"] = "$(rubylibprefix)/site_ruby"
   CONFIG["rubyarchdir"] = "$(rubylibdir)/$(arch)"
   CONFIG["rubylibdir"] = "$(rubylibprefix)/$(ruby_version)"
-  CONFIG["ruby_version"] = "3.3.0"
+  CONFIG["ruby_version"] = "3.4.0"
   CONFIG["sitearch"] = "$(arch)"
   CONFIG["arch"] = "powerpc-netbsd"
   CONFIG["sitearchincludedir"] = "$(includedir)/$(sitearch)"
@@ -64,7 +64,7 @@ module RbConfig
   CONFIG["archlibdir"] = "$(libdir)/$(arch)"
   CONFIG["libdirname"] = "libdir"
   CONFIG["RUBY_EXEC_PREFIX"] = "/usr/pkg"
-  CONFIG["RUBY_LIB_VERSION"] = "3.3.0"
+  CONFIG["RUBY_LIB_VERSION"] = "3.4.0"
   CONFIG["RUBY_LIB_VERSION_STYLE"] = ""
   CONFIG["RI_BASE_NAME"] = "ri"
   CONFIG["ridir"] = "$(datarootdir)/$(RI_BASE_NAME)"
@@ -97,6 +97,7 @@ module RbConfig
   CONFIG["rubyw_install_name"] = ""
   CONFIG["EXTDLDFLAGS"] = ""
   CONFIG["EXTLDFLAGS"] = ""
+  CONFIG["hardenflags"] = "-U_FORTIFY_SOURCE -D_FORTIFY_SOURCE=2"
   CONFIG["strict_warnflags"] = ""
   CONFIG["warnflags"] = "-Wall -Wextra -Wdeprecated-declarations -Wdiv-by-zero -Wduplicated-cond -Wimplicit-function-declaration -Wimplicit-int -Wpointer-arith -Wwrite-strings -Wold-style-definition -Wimplicit-fallthrough=0 -Wmissing-noreturn -Wno-cast-function-type -Wno-constant-logical-operand -Wno-long-long -Wno-missing-field-initializers -Wno-overlength-strings -Wno-packed-bitfield-compat -Wno-parentheses-equality -Wno-self-assign -Wno-tautological-compare -Wno-unused-parameter -Wno-unused-value -Wsuggest-attribute=format -Wsuggest-attribute=noreturn -Wunused-variable -Wmisleading-indentation -Wundef"
   CONFIG["debugflags"] = "-ggdb3"
@@ -112,6 +113,7 @@ module RbConfig
   CONFIG["CARGO"] = ""
   CONFIG["RUSTC"] = "no"
   CONFIG["INSTALL_STATIC_LIBRARY"] = "yes"
+  CONFIG["modular_gc_dir"] = ""
   CONFIG["EXECUTABLE_EXTS"] = ""
   CONFIG["ARCHFILE"] = ""
   CONFIG["LIBRUBY_RELATIVE"] = "no"
@@ -125,9 +127,9 @@ module RbConfig
   CONFIG["TRY_LINK"] = ""
   CONFIG["PRELOADENV"] = "LD_PRELOAD"
   CONFIG["LIBPATHENV"] = "LD_LIBRARY_PATH"
-  CONFIG["RPATHFLAG"] = " -Wl,-rpath,%1$-s"
-  CONFIG["LIBPATHFLAG"] = " -L%1$-s"
-  CONFIG["LINK_SO"] = ""
+  CONFIG["RPATHFLAG"] = "-Wl,-rpath,%1$-s"
+  CONFIG["LIBPATHFLAG"] = "-L%1$-s"
+  CONFIG["LINK_SO"] = "\n$(POSTLINK)"
   CONFIG["ADDITIONAL_DLDFLAGS"] = ""
   CONFIG["ENCSTATIC"] = ""
   CONFIG["EXTSTATIC"] = ""
@@ -167,10 +169,9 @@ module RbConfig
   CONFIG["LN_S"] = "ln -s"
   CONFIG["DLLWRAP"] = ""
   CONFIG["WINDRES"] = ""
-  CONFIG["ASFLAGS"] = ""
   CONFIG["ARFLAGS"] = "rcD "
   CONFIG["try_header"] = ""
-  CONFIG["CC_VERSION_MESSAGE"] = "gcc (nb3 20190319) 7.4.0\nCopyright (C) 2017 Free Software Foundation, Inc.\nThis is free software; see the source for copying conditions.  There is NO\nwarranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."
+  CONFIG["CC_VERSION_MESSAGE"] = "gcc (nb2 20230710) 10.5.0\nCopyright (C) 2020 Free Software Foundation, Inc.\nThis is free software; see the source for copying conditions.  There is NO\nwarranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."
   CONFIG["CC_VERSION"] = "$(CC) --version"
   CONFIG["CSRCFLAG"] = ""
   CONFIG["COUTFLAG"] = "-o "
@@ -196,6 +197,7 @@ module RbConfig
   CONFIG["CC"] = "gcc"
   CONFIG["wasmoptflags"] = ""
   CONFIG["WASMOPT"] = ""
+  CONFIG["config_target"] = "powerpc--netbsd"
   CONFIG["target_os"] = "netbsd"
   CONFIG["target_vendor"] = ""
   CONFIG["target_cpu"] = "powerpc"
@@ -217,7 +219,7 @@ module RbConfig
   CONFIG["GIT"] = "never-use"
   CONFIG["cxxflags"] = ""
   CONFIG["cppflags"] = ""
-  CONFIG["cflags"] = "$(optflags) $(debugflags) $(warnflags)"
+  CONFIG["cflags"] = "$(hardenflags)  $(optflags) $(debugflags) $(warnflags)"
   CONFIG["MAKEDIRS"] = "/bin/mkdir -p"
   CONFIG["target_alias"] = ""
   CONFIG["host_alias"] = "$(target_alias)"
@@ -247,7 +249,7 @@ module RbConfig
   CONFIG["libexecdir"] = "$(exec_prefix)/libexec"
   CONFIG["sbindir"] = "$(exec_prefix)/sbin"
   CONFIG["bindir"] = "$(exec_prefix)/bin"
-  CONFIG["program_transform_name"] = "s&$$&33&;s&^&&"
+  CONFIG["program_transform_name"] = "s&$$&34&;s&^&&"
   CONFIG["exec_prefix"] = "$(prefix)"
   CONFIG["PACKAGE_URL"] = ""
   CONFIG["PACKAGE_BUGREPORT"] = ""
